==> carbon-component-mapper-3.11.4.tgz: package/esm/slider/slider.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import CarbonSlider from "carbon-components-react/es/components/Slider/Slider.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Slider = function Slider(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      isRequired = _useFieldApi.isRequired,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "meta", "isRequired", "validateOnMount", "helperText", "WrapperProps"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonSlider, _extends({}, input, {
    value: Number(input.value) || 0,
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    min: 0,
    max: 100,
    required: isRequired
  }, rest)), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

Slider.propTypes = {
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  WrapperProps: PropTypes.object
};
export default Slider;

==> carbon-component-mapper-3.16.9.tgz: package/esm/slider/slider.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "meta", "isRequired", "validateOnMount", "helperText", "WrapperProps"];
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import CarbonSlider from "carbon-components-react/es/components/Slider/Slider.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Slider = function Slider(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      isRequired = _useFieldApi.isRequired,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(CarbonSlider, _extends({}, input, {
    value: Number(input.value) || 0,
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    min: 0,
    max: 100,
    required: isRequired
  }, rest)), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

Slider.propTypes = {
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  WrapperProps: PropTypes.object
};
export default Slider;
